# Replication code for Ryan Brutger and Amy Pond's manuscript (Last updated October 1, 2024)
# "International Economic Relations and American Support for Antitrust Policy"
# Code for the appendix is in the companion R script


# Code was run on R version 4.0.1 (2020-06-06) -- "See Things Now"
# Using MAcBook Pro using macOS Catalina, with 2.9GHz Dual-Core Intel Core i5

# load packages
#install.packages("pacman")
pacman::p_load(dplyr, ggplot2, quanteda, plotly, foreign, interplot, plm, reshape2, lda,
               countrycode, sandwich, lmtest, MASS, RColorBrewer, states, mice, VIM, 
               margins, clusterSEs, optimx, coefplot, systemfit, randomizr, estimatr, ri2,
               stargazer, fastDummies, cowplot, egg, cobalt, readr, xtable, sjPlot, sjmisc, weights, anesrake) 

# Set working directory 
# Read data file
data <- read_csv("Replication_Survey_Data.csv")

# Create DV 
data$AT_Strength <- ifelse(is.na(data$AT_Strength1)==FALSE, data$AT_Strength1, data$AT_Strength2)

## Create indicator variables
data$dem <- ifelse(data$party==1, 1, 0) # democrat
data$rep <- ifelse(data$party==2, 1, 0) # republican
data$college <- ifelse(data$edu>3, 1, 0) #has a 2 or 4 yr degree or higher
data$male <- ifelse(data$gender1==1, 1, 0) #male
data$NatSup2 <- ifelse(data$NatSup2==1, 4, ifelse(data$NatSup2==2, 3, ifelse(data$NatSup2==3, 2, ifelse(data$NatSup2==4, 1, NA)))) #recode so high values are superior
data$NatSup <- data$NatSup1 + data$NatSup2 #aggregated national superiorty measure
data$high.income <- ifelse(data$hh_income>3, 1, 0) # high household income , indicator if it is higher than $75,000
data$Tech <- ifelse(is.na(data$Tech)==TRUE, 0, 1) # mentioned tech companies in free responses
data$China <- ifelse(is.na(data$China)==TRUE, 0, 1) #mentioned China in free responses

#Rescaling function for more easily interpretable results (zero to one interval)
rescale <- function(x){
  return((x-min(x,na.rm=TRUE))/(max(x-min(x,na.rm=TRUE),na.rm=TRUE)))
}
data$NatSup <- rescale(data$NatSup)

# Create Treatment Indicators such that those in the Pure Control are noted as such (and not also as another treatment)
data$CompEff <- ifelse(data$Number==1, 0, data$CompEff) #Efficiency treatment indicator
data$AmerDisad<- ifelse(data$Number==1, 0, data$AmerDisad) # American Disadvantage treatment indicator
data$PureControl  <- ifelse(data$Number==1 & is.na(data$Number)==FALSE, 1, 0) # Pure Control indicator

# create indicator variables for those who support strengthening antitrust 
data$AT_StrengthPos <- ifelse(data$AT_Strength>3, 1, 0)

# Indicator for Foreign Companies Targeted
data$Foreign <- ifelse(data$Dom1==0, 1, 0) # Create "Foreign Targeting" treatment indicator


## Media analysis for paper
#load data of annual count of US Antitrust media
AT_annual <- read.csv("Antitrust Media Coding - Yearly Count.csv") 

# Figure 1 of paper - Bar plot, coverage of antitrust
# export as 5 x 4 pdf
barplot(AT_annual$Count, 
        names.arg = AT_annual$Year, 
        xlab = "Year", 
        ylab = "News Stories", 
        main = "Coverage of Antitrust from 1990-2021",
        ylim = c(0, 15000), # Set the y-axis limits to 0-100%
        col = "black",
        border = "black",
        args.legend = list(x = "topright")
        # Create a custom function to format the y-axis labels as percentages
        #axisFUN = function(x, ...) paste0(x, "%")
)

#### Coded Media Data ####
# load data of coded media coverage
AT_med <- read.csv("Antitrust_Media_Coding.csv") # load RA coded media data from NexusUni 
AT_med$date <-  as.Date(AT_med$Date,'%m/%d/%Y')
AT_med$Year <- as.numeric(format(AT_med$date,'%Y'))

AT_med_agg <- aggregate(list(AT_med$Competition, AT_med$PunishFirm, AT_med$HurtUSComp, AT_med$HelpsUSComp, AT_med$Fairness, AT_med$IntlCordEnf), 
                        by = list(AT_med$Year), FUN = sum, na.rm=T)
colnames(AT_med_agg) <- c("Year", "Competition", "Punish_Firms", "Hurts_US_Comp", "Helps_US_Comp", "Fairness", "International")

# Create a single measure that addressess any International/Foreign articles (Intl, Helps, Hurts)
AT_med$FullIntl <- ifelse(AT_med$IntlCordEnf==1, 1, ifelse(AT_med$HelpsUSComp==1, 1, ifelse(AT_med$HelpsUSComp==1, 1, 0)))


# Create a single measure that addressess any Democracy/Political Power articles 
AT_med$DemPwr <- ifelse(AT_med$Democracy==1, 1, ifelse(AT_med$PolPwr==1, 1, 0))


# create a measure of the proportion of coverage for each year that is of X type
year <-numeric(length = length(1990:2021))
AT.obs.per.yr <-numeric(length = length(1990:2021))
AT.comp.per.yr <-numeric(length = length(1990:2021))
AT.prop.comp <-numeric(length = length(1990:2021)) 
AT.prop.hurts <-numeric(length = length(1990:2021))
AT.helps.per.yr <-numeric(length = length(1990:2021))
AT.intl.per.yr <-numeric(length = length(1990:2021))
AT.prop.intl <-numeric(length = length(1990:2021))
AT.effic.per.yr <-numeric(length = length(1990:2021))
AT.prop.effic <-numeric(length = length(1990:2021))
AT.fullintl.per.yr <-numeric(length = length(1990:2021))
AT.prop.fullintl <-numeric(length = length(1990:2021))

year <- c()
AT.obs.per.yr <- c()
AT.comp.per.yr <-c()
AT.prop.comp <- c() 
AT.prop.hurts <- c()
AT.helps.per.yr <- c()
AT.effic.per.yr <- c()
AT.prop.effic <- c()
AT.fullintl.per.yr <- c()
AT.prop.fullintl <- c()

AT_df <- data.frame(matrix(ncol=0, nrow =32))

loop_output <- capture.output({
  for (i in 1990:2021){
    AT_df$year[i -1989]<-i
    AT_df$AT.obs.per.yr[i -1989] <- length(AT_med$Year[AT_med$Year==i])
    AT_df$AT.comp.per.yr[i -1989] <- length(AT_med$Year[AT_med$Competition==1 & AT_med$Year==i])
    AT_df$AT.effic.per.yr[i -1989] <-length(AT_med$Year[AT_med$Efficiency ==1 & AT_med$Year==i])
    AT_df$AT.fullintl.per.yr[i -1989] <-length(AT_med$Year[AT_med$FullIntl ==1 & AT_med$Year==i])
    AT_df$AT.hurts.per.yr[i -1989] <- length(AT_med$Year[AT_med$HurtUSComp ==1 & AT_med$Year==i])
    AT_df$AT.helps.per.yr[i -1989] <- length(AT_med$Year[AT_med$HelpsUSComp ==1 & AT_med$Year==i])
  }})

AT_df$AT.prop.comp <- AT_df$AT.comp.per.yr/AT_df$AT.obs.per.yr
AT_df$AT.prop.effic <- AT_df$AT.effic.per.yr/AT_df$AT.obs.per.yr
AT_df$AT.prop.fullintl <- AT_df$AT.fullintl.per.yr/AT_df$AT.obs.per.yr
AT_df$AT.prop.hurts <- AT_df$AT.hurts.per.yr/AT_df$AT.obs.per.yr
AT_df$AT.prop.helps <- AT_df$AT.helps.per.yr/AT_df$AT.obs.per.yr


# create a measure of the proportion of coverage for each 4-year window that is of X type
AT_4yr <- data.frame(matrix(ncol=0, nrow =8))
AT_4yr$period <- c()
AT_4yr$comp.prop.per <- c()
comp.prop1 <- c()
AT_4yr$effic.prop.per <- c()
effic.prop1 <- c()
AT_4yr$fullintl.prop.per <- c()
fullintl.prop1 <- c()



loop_output <- capture.output({
  for(j in c(1990, 1994, 1998, 2002, 2006, 2010, 2014, 2018)){
    for(k in 0:3){
      time  <- j+k
      period <- ifelse(j==1990, 1, ifelse(j==1994, 2, ifelse(j==1998, 3, ifelse(j==2002, 4, ifelse(j==2006, 5, ifelse(j==2010, 6, ifelse(j==2014, 7, ifelse(j==2018, 8, NA))))))))
      AT_4yr$period[period]<- period
      comp.prop1[1] <- ifelse(k==0, AT_df$AT.prop.comp[AT_df$year==time], comp.prop1[1])
      comp.prop1[2] <- ifelse(k==1, AT_df$AT.prop.comp[AT_df$year==time], comp.prop1[2])
      comp.prop1[3] <- ifelse(k==2, AT_df$AT.prop.comp[AT_df$year==time], comp.prop1[3])
      comp.prop1[4] <- ifelse(k==3, AT_df$AT.prop.comp[AT_df$year==time], comp.prop1[4])
      AT_4yr$comp.prop.per[period]   <- ((comp.prop1[1] + comp.prop1[2] + comp.prop1[3] + comp.prop1[4])/4)
      effic.prop1[1] <- ifelse(k==0, AT_df$AT.prop.effic[AT_df$year==time], effic.prop1[1])
      effic.prop1[2] <- ifelse(k==1, AT_df$AT.prop.effic[AT_df$year==time], effic.prop1[2])
      effic.prop1[3] <- ifelse(k==2, AT_df$AT.prop.effic[AT_df$year==time], effic.prop1[3])
      effic.prop1[4] <- ifelse(k==3, AT_df$AT.prop.effic[AT_df$year==time], effic.prop1[4])
      AT_4yr$effic.prop.per[period]   <- ((effic.prop1[1] + effic.prop1[2] + effic.prop1[3] + effic.prop1[4])/4)
      fullintl.prop1[1] <- ifelse(k==0, AT_df$AT.prop.fullintl[AT_df$year==time], fullintl.prop1[1])
      fullintl.prop1[2] <- ifelse(k==1, AT_df$AT.prop.fullintl[AT_df$year==time], fullintl.prop1[2])
      fullintl.prop1[3] <- ifelse(k==2, AT_df$AT.prop.fullintl[AT_df$year==time], fullintl.prop1[3])
      fullintl.prop1[4] <- ifelse(k==3, AT_df$AT.prop.fullintl[AT_df$year==time], fullintl.prop1[4])
      AT_4yr$fullintl.prop.per[period]   <- ((fullintl.prop1[1] + fullintl.prop1[2] + fullintl.prop1[3] + fullintl.prop1[4])/4)
    }}})

# Generate bar plots that comprise Figure 2 of paper
# Bar plot, Competition by percent
comp_perc <- AT_4yr$comp.prop.per * 100
barplot(comp_perc, 
        #names.arg = AT_4yr$period, 
        xlab = "Four Year Intervals 1990-2021", cex.axis = 1.5, cex.lab = 1.5, cex.main = 1.5,
        #    names.arg=c(1990 ,1994, 1998, 2002, 2006, 2010, 2014, 2020), las=2,
        ylab = "", 
        main = "Competition Articles", 
        ylim = c(0, 80), # Set the y-axis limits to 0-100%
        col = "black",
        border = "black",
        #density = 10, # Add pattern to the bars
        args.legend = list(x = "topright")
        # Create a custom function to format the y-axis labels as percentages
        #axisFUN = function(x, ...) paste0(x, "%")
)
# export as 5 x 4 pdf

# Bar plot, Efficiency by percent
effic_perc <- AT_4yr$effic.prop.per * 100
barplot(effic_perc, 
        #names.arg = AT_4yr$period, 
        xlab = "Four Year Intervals 1990-2021", cex.axis = 1.5, cex.lab = 1.5, cex.main = 1.5,
        ylab = "Percent (%)", 
        main = "Efficiency Articles",
        ylim = c(0, 80), # Set the y-axis limits to 0-100%
        col = "black",
        border = "black",
        #density = 10, # Add pattern to the bars
        args.legend = list(x = "topright")
        # Create a custom function to format the y-axis labels as percentages
        #axisFUN = function(x, ...) paste0(x, "%")
)

# Bar plot, Full International by percent
fullintl_perc <- AT_4yr$fullintl.prop.per * 100
barplot(fullintl_perc, 
        #names.arg = AT_4yr$period, 
        xlab = "Four Year Intervals 1990-2021", cex.axis = 1.5, cex.lab = 1.5, cex.main = 1.5,
        ylab = "Percent (%)", 
        main = "International Focused Articles",
        ylim = c(0, 80), # Set the y-axis limits to 0-100%
        col = "black",
        border = "black",
        #density = 10, # Add pattern to the bars
        args.legend = list(x = "topright")
        # Create a custom function to format the y-axis labels as percentages
        #axisFUN = function(x, ...) paste0(x, "%")
)

# for analysis of change in proportion of articles that hurt U.S. firms, reported in text
hurts.yr.model <- lm(AT.prop.hurts ~ year, data=AT_df)
summary(hurts.yr.model) #p = 0.563

# for analysis of change in proportion of articles that helps U.S. firms, reported in text
helps.yr.model <- lm(AT.prop.helps ~ year, data=AT_df) 
summary(helps.yr.model) # p = 0.087

##
## The following is the analysis of our survey experiment
##

# Figure 3 - Create baseline histogram using domestic targeting control
mean(data$AT_StrengthPos[data$Control==1], na.rm=TRUE) #59%
mean(data$AT_StrengthPos[data$Control==1 & data$dem==1], na.rm=TRUE) #67%
mean(data$AT_StrengthPos[data$Control==1 & data$rep==1], na.rm=TRUE) #59%

# Histogram of Baseline
# Generate Figure 3 of the paper
base.names <- c("Full Sample", "Democrats", "Republicans")
base.opin <- c(.59, .67, .59)
color <- c("darkgray", "lightgray", "black")

#Figure 3 - export as 4 x 6 
par(mar=c(4,6,1,1))
barplot(base.opin, main="", xlab="", ylim=c(0,.85), 
        ylab="", cex.lab=1.3, names.arg=base.names, cex.names=1.3, col=color, space=c(.4, .4, .4))
#text(2.2, .7, labels = "Strengthen Laws", cex=1.5)
mtext("Proportion Supporting \n Stronger Antitrust Laws", side=2, line = 2.5, cex=1.3)

#Drop pure control, so that the control has domestic/foreign specified as do the treatments
data <- subset(data[data$PureControl==0, ])

data.dom <- subset(data[data$Foreign==0 & is.na(data$Foreign)==FALSE, ])
data.for <- subset(data[data$Foreign==1 & is.na(data$Foreign)==FALSE, ])

# Calcualte n for each cell reported in Figure 4 of paper
table(data$CompEff) #n=889
table(data$CompEff[data$Foreign==0])# n=438 in Efficiency + Domestic
table(data$CompEff[data$Foreign==1]) #n=451 in Efficiency + Foreign
table(data$Foreign[data$CompEff==0]) #n=458 in Pure Foreign Targeting
table(data$AmerDisad) #n=856 in Amer Disad + Domestic
table(data$Foreign[data$AmerDisad==0 & data$CompEff==0]) #448 in Domestic targeting Control

#Effects among domestic targeting only for Figure 5 of paper

AT.Strength.dom <- lm(AT_Strength ~ AmerDisad + CompEff, data = data[data$Foreign==0, ])
summary(AT.Strength.dom)

CI.Strength <- confint(AT.Strength.dom, level = 0.95)
Ci.Up.Strength <- c(CI.Strength[5], CI.Strength[6])
Ci.Low.Strength <- c(CI.Strength[2], CI.Strength[3])
Coef.Strength <- coef(AT.Strength.dom)
Coef.Strength2 <- c(Coef.Strength[2], Coef.Strength[3])

names <- c("American", "National")
names2 <- c("Disadvantage", "Efficiency")

#Figure 5 of paper, export as 4x4 

par(mar=c(4,5,1,1))
plot(1:2, Coef.Strength2 , main = "", 
     ylab = "", xlab = "", cex.lab=2,
     ylim = c(-.4, .4), xlim = c(0.75, 2.25), pch = 19, type = "p", xaxt="n", cex=1)
mtext("Treatment Effects", side=2, at=0, cex=1.5, line=2.5)
abline(h=0, col="blue", lty=2)
for(i in 1:length(Coef.Strength2)){
  lines(c(i,i), c(Ci.Up.Strength[i], Ci.Low.Strength[i]))
  mtext(names[i], side=1, at=i, .7, cex=1.5)
  mtext(names2[i], side=1, at=i, 2.1, cex=1.5)
}


# Effect mentioned in text
t.test(data$AT_StrengthPos[data$Control==1], data$AT_StrengthPos[data$AmerDisad==1])
# 58.7=control, 48.5=AmerDisad, p<0.01
58.7-48.5# 10%

# Measure the effect of foreign targeting
# For the whole sample, dropping American disadvantage

# Changes in percent supporting

AT.Strength.for.full <- lm(AT_Strength ~ Foreign, data = data[data$AmerDisad==0,])
summary(AT.Strength.for.full) # effect of foreign targeting for full sample reported in text 0.07, p<0.08

CI.Strength.for.full <- confint(AT.Strength.for.full, level = 0.95)
Coef.Strength.for.full <- coef(AT.Strength.for.full)

# Effect of Foreign in the Control
AT.Strength.for <- lm(AT_Strength ~ Foreign, data = data[data$Control==1, ])

CI.Strength.for <- confint(AT.Strength.for, level = 0.95)
Coef.Strength.for <- coef(AT.Strength.for)

# Effect of Foreign in the Efficiency Treatment
AT.Strength.for.eff <- lm(AT_Strength ~ Foreign, data = data[data$CompEff==1, ])

CI.Strength.for.eff <- confint(AT.Strength.for.eff, level = 0.95)
Coef.Strength.for.eff <- coef(AT.Strength.for.eff)

#Figure 6 of paper, export as 4x6
par(mar=c(4,5,1,1))
plot(1:1, Coef.Strength.for.full[2] , main = "", 
     ylab = "", xlab = "", cex.lab=2,
     ylim = c(-.5, .5), xlim = c(0.85, 3.25), pch = 19, type = "p", xaxt="n", cex=1)
abline(h=0, col="blue", lty=2)
lines(c(1,1), c(CI.Strength.for.full[2],CI.Strength.for.full[4]))
points(2, Coef.Strength.for[2], pch=19, cex=1)
lines(c(2,2), c(CI.Strength.for[2],CI.Strength.for[4]))
points(3, Coef.Strength.for.eff[2], pch=19, cex=1)
lines(c(3,3), c(CI.Strength.for.eff[2],CI.Strength.for.eff[4]))
mtext("Effect of Foreign Targeting", side=2, at=0, cex=1.7, line=2.5)
mtext("Aggregate", side=1, at=1, .7, cex=1.5)
mtext("Results", side=1, at=1, 2.2, cex=1.5)
mtext("Control", side=1, at=2, .7, cex=1.5)
mtext("National", side=1, at=3, .7, cex=1.5)
mtext("Efficiency", side=1, at=3, 2.2, cex=1.5)


# Now with interaction with Nat. Superiority, reported in Table 2 of manuscript 
AT.Strength.for.NS <- lm(AT_Strength ~ Foreign*NatSup, data = data[data$AmerDisad==0,])
# Same with demographic controls 
AT.Strength.for.NS.c <- lm(AT_Strength ~ Foreign*NatSup+ male + ideology + college + high.income, data = data[data$AmerDisad==0,])

#Interaction effect with National Superiority when Foreign==0
AT.Strength.NatSup.inter <- lm(AT_Strength ~ AmerDisad*NatSup + CompEff*NatSup, data = data[data$Foreign==0, ])
# Same models with controls
AT.Strength.NatSup.inter.c <- lm(AT_Strength ~ AmerDisad*NatSup + CompEff*NatSup + male + ideology + college + high.income, data = data[data$Foreign==0, ])
# Table 2 of paper
stargazer(AT.Strength.for.NS, AT.Strength.for.NS.c, AT.Strength.NatSup.inter, AT.Strength.NatSup.inter.c, omit.stat = c("rsq", "adj.rsq", "ser", "f"), column.labels = c("Foreign Targeting", "Foreign Targeting", "Amer. Disadvantage", "Amer. Disadvantage"))

#
# Marginal Effects Plots
#

# For marginal effects, first run "interaction_plots.R" to generate functions created by Anton Strezhnev 06/17/2013
# The following lines of code for the marginal effects plots are from Strezhnev's "interaction_plots.R
interaction_plot_continuous <- function(model, effect, moderator, interaction, varcov="default", minimum="min", maximum="max", incr="default", num_points = 50, conf=.95, mean=FALSE, median=FALSE, alph=80, rugplot=T, histogram=F, title="Marginal effects plot", xlabel="Value of moderator", ylabel="Estimated marginal coefficient"){
  
  # Define a function to make colors transparent
  makeTransparent<-function(someColor, alpha=alph){
    newColor<-col2rgb(someColor)
    apply(newColor, 2, function(curcoldata){rgb(red=curcoldata[1], green=curcoldata[2],
                                                blue=curcoldata[3],alpha=alpha, maxColorValue=255)})
  }
  
  # Extract Variance Covariance matrix
  if (varcov == "default"){
    covMat = vcov(model)
  }else{
    covMat = varcov
  }
  
  # Extract the data frame of the model
  mod_frame = model.frame(model)
  
  # Get coefficients of variables
  beta_1 = model$coefficients[[effect]]
  beta_3 = model$coefficients[[interaction]]
  
  # Set range of the moderator variable
  # Minimum
  if (minimum == "min"){
    min_val = min(mod_frame[[moderator]])
  }else{
    min_val = minimum
  }
  # Maximum
  if (maximum == "max"){
    max_val = max(mod_frame[[moderator]])
  }else{
    max_val = maximum
  }
  
  # Check if minimum smaller than maximum
  if (min_val > max_val){
    stop("Error: Minimum moderator value greater than maximum value.")
  }
  
  # Determine intervals between values of the moderator
  if (incr == "default"){
    increment = (max_val - min_val)/(num_points - 1)
  }else{
    increment = incr
  }
  
  # Create list of moderator values at which marginal effect is evaluated
  x_2 <- seq(from=min_val, to=max_val, by=increment)
  
  # Compute marginal effects
  delta_1 = beta_1 + beta_3*x_2
  
  # Compute variances
  var_1 = covMat[effect,effect] + (x_2^2)*covMat[interaction, interaction] + 2*x_2*covMat[effect, interaction]
  
  # Standard errors
  se_1 = sqrt(var_1)
  
  # Upper and lower confidence bounds
  z_score = qnorm(1 - ((1 - conf)/2))
  upper_bound = delta_1 + z_score*se_1
  lower_bound = delta_1 - z_score*se_1
  
  # Determine the bounds of the graphing area
  max_y = max(upper_bound)
  min_y = min(lower_bound)
  
  # Make the histogram color
  hist_col = makeTransparent("grey")
  
  # Initialize plotting window
  #  plot(x=c(), y=c(), ylim=c(min_y, max_y), xlim=c(min_val, max_val), xlab=xlabel, ylab=ylabel, main=title) # this is the default line
  plot(x=c(), y=c(), ylim=c(-0.6, 0.6), xlim=c(min_val, max_val), xlab=xlabel, ylab=ylabel, main=title) # this line customizes the y-axis
  
  
  # Plot estimated effects
  lines(y=delta_1, x=x_2)
  lines(y=upper_bound, x=x_2, lty=2)
  lines(y=lower_bound, x=x_2, lty=2)
  
  # Add a dashed horizontal line for zero
  abline(h=0, lty=3)
  
  # Add a vertical line at the mean
  if (mean){
    abline(v = mean(mod_frame[[moderator]]), lty=2, col="red")
  }
  
  # Add a vertical line at the median
  if (median){
    abline(v = median(mod_frame[[moderator]]), lty=3, col="blue")
  }
  
  # Add Rug plot
  if (rugplot){
    rug(mod_frame[[moderator]])
  }
  # Add Histogram (Histogram only plots when minimum and maximum are the min/max of the moderator)
  if (histogram & minimum=="min" & maximum=="max"){
    par(new=T)
    hist(mod_frame[[moderator]], axes=F, xlab="", ylab="",main="", border=hist_col, col=hist_col)
  }
}

#Rename variables for figure
data$Strengthen_Laws <- data$AT_Strength
data$National_Superiority <- data$NatSup
data$Foreign_Targeting <- data$Foreign
data$American_Disadvantaged <- data$AmerDisad
data$National_Efficiency<-data$CompEff

#Marginal Effects Plot: National superiority * American Disadvantage
Disad.AtStrength.ns.inter <- lm(AT_Strength ~ National_Superiority*American_Disadvantaged + CompEff*National_Superiority, data = data[data$Foreign==0 & (data$AmerDisad==1 | data$Control==1), ])
AT.Strength.NatSup.inter <- lm(AT_Strength ~ AmerDisad*NatSup + CompEff*NatSup, data = data[data$Foreign==0 & data$CompPrices==0, ])


#Export as 3x4 for right panel of Figure 7 of paper
par(mar=c(4,5,2,1))
interaction_plot_continuous(Disad.AtStrength.ns.inter, effect="American_Disadvantaged", moderator="National_Superiority", 
                            interaction="National_Superiority:American_Disadvantaged", mean=T, title="American Disadvantage",
                            xlabel="National Superiority", ylabel="Marginal effect \n of American Disadvantage")


#Marginal Effects Plot: National Superiority * Foreign Targeting  
AT.Strength.for.NS <- lm(Strengthen_Laws ~ National_Superiority*Foreign_Targeting, data = data[data$AmerDisad==0,])
#Export as 3x4 for left panel of Figure 7 of paper
par(mar=c(4,5,2,1))
interaction_plot_continuous(AT.Strength.for.NS, effect="Foreign_Targeting", moderator="National_Superiority", 
                            interaction="National_Superiority:Foreign_Targeting", mean=T, title="Foreign Targeting",
                            xlabel="National Superiority", ylabel="Marginal effect \n of Foreign Targeting")

